A simple cooperative distributed queuing system
===============================================

Magnolia is a simple cooperative distributed queuing system. What does that mean? Well, it means that its a way of passing messages requesting work be done between machines, without a central server being involved. Instead the machines collaborate to queue the work in the correct place, and then ensure the work isn't lost in the case of a crash.
